@@ -50,7 +50,7 @@ structure(list(coords = structure(c(5710, 5727, 5745, 5764, 5781,
 "152", "153", "154", "155", "156", "157", "158", "159", "160", 
 "161", "162", "163", "164", "165", "166", "167", "168", "169", 
 "170", "171", "172", "173", "174", "175", "176", "177", "178"
-), c("leste", "norte"))), data = c(52, 57, 72, 74, 68, 45, 47, 
+), c("east", "north"))), data = c(52, 57, 72, 74, 68, 45, 47, 
 49, 38, 53, 60, 47, 34, 56, 66, 53, 43, 42, 49, 45, 53, 38, 47, 
 35, 60, 45, 60, 61, 58, 44, 50, 47, 49, 46, 43, 56, 43, 50, 61, 
 57, 57, 42, 41, 54, 46, 50, 43, 72, 56, 38, 64, 56, 68, 61, 50, 
@@ -107,24 +107,24 @@ structure(list(coords = structure(c(5710, 5727, 5745, 5764, 5781,
 "152", "153", "154", "155", "156", "157", "158", "159", "160", 
 "161", "162", "163", "164", "165", "166", "167", "168", "169", 
 "170", "171", "172", "173", "174", "175", "176", "177", "178"
-), class = "data.frame"), borders = structure(list(leste = c(5340, 
+), class = "data.frame"), borders = structure(list(east = c(5340, 
 5590, 5990, 5990, 5780, 5590, 5350, 5150, 4920, 4920, 5150, 5250, 
-5220, 5340), norte = c(5800, 5690, 5690, 5100, 4800, 4800, 4900, 
-4920, 4900, 5000, 5370, 5370, 5700, 5800)), .Names = c("leste", 
-"norte"), row.names = c("2", "1", "8", "11", "10", "9", "81", 
+5220, 5340), north = c(5800, 5690, 5690, 5100, 4800, 4800, 4900, 
+4920, 4900, 5000, 5370, 5370, 5700, 5800)), .Names = c("east", 
+"north"), row.names = c("2", "1", "8", "11", "10", "9", "81", 
 "7", "6", "5", "4", "41", "3", "22"), class = "data.frame"), 
-    reg1 = structure(list(leste = c(5590, 5340, 5220, 5250, 5350, 
-    5450, 5510, 5590), norte = c(5690, 5800, 5700, 5370, 5370, 
-    5500, 5600, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
+    reg1 = structure(list(east = c(5590, 5340, 5220, 5250, 5350, 
+    5450, 5510, 5590), north = c(5690, 5800, 5700, 5370, 5370, 
+    5500, 5600, 5690)), .Names = c("east", "north"), row.names = c("1", 
     "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
-    reg2 = structure(list(leste = c(5990, 5590, 5350, 5450, 5510, 
-    5590, 5800, 5990), norte = c(5100, 5300, 5370, 5500, 5600, 
-    5690, 5690, 5690)), .Names = c("leste", "norte"), row.names = c("1", 
+    reg2 = structure(list(east = c(5990, 5590, 5350, 5450, 5510, 
+    5590, 5800, 5990), north = c(5100, 5300, 5370, 5500, 5600, 
+    5690, 5690, 5690)), .Names = c("east", "north"), row.names = c("1", 
     "2", "3", "4", "5", "6", "7", "8"), class = "data.frame"), 
-    reg3 = structure(list(leste = c(5990, 5590, 5350, 5150, 4920, 
-    4920, 5150, 5350, 5590, 5780), norte = c(5100, 5300, 5370, 
-    5370, 5000, 4900, 4920, 4900, 4800, 4800)), .Names = c("leste", 
-    "norte"), row.names = c("1", "2", "3", "4", "5", "6", "7", 
+    reg3 = structure(list(east = c(5990, 5590, 5350, 5150, 4920, 
+    4920, 5150, 5350, 5590, 5780), north = c(5100, 5300, 5370, 
+    5370, 5000, 4900, 4920, 4900, 4800, 4800)), .Names = c("east", 
+    "north"), row.names = c("1", "2", "3", "4", "5", "6", "7", 
     "8", "9", "10"), class = "data.frame")),
           .Names = c("coords", "data", "covariate", 
             "borders", "reg1", "reg2", "reg3"), class = "geodata")
